﻿using System;
using System.ComponentModel;
using System.Drawing;
using System.Windows.Forms;
    
using System.Media; // Для звука 
    
namespace MyCompany.UserControls
{
    public partial class SoundButton : Button
    {
        public SoundButton()
        {
            InitializeComponent();
        }
    
        public SoundButton(IContainer container)
        {
            container.Add(this);
    
            InitializeComponent();
        }
    
        // Создаем объект-проигрыватель как 
        // поле класса для управления звуком
        SoundPlayer soundPlayer = new SoundPlayer();
    
        // Свойство подключения звука к проигрывателю из файла
        public string WaveFile
        {
            get
            {
                // Что загружено для проигрывания
                return soundPlayer.SoundLocation;
            }
            set
            {
                // Подключить файл с диска или URL
                soundPlayer.SoundLocation = value;
            }
        }
    
        // Свойство подключения звука к проигрывателю из потока
        public System.IO.Stream WaveStream
        {
            get
            {
                // Вернуть ссылку на загруженный в поток файл
                return soundPlayer.Stream;
            }
            set
            {
                // Подключить файл к потоку
                soundPlayer.Stream = value;
                // Загрузить асинхронно (в фоновом режиме)
                soundPlayer.LoadAsync();
            }
        }
    
        // Переопределяем виртуальный метод класса Control,
        // чтобы начать проигрывание по щелчку на кнопке
        protected override void OnClick(EventArgs e)
        {
            // Если имя экземпляра кнопки - "Web", 
            // то вместо адресации к удаленному звуку
            // в Internet проигрываем стандартный звуковой
            // файл локального компьютера, встроенный
            // в класс SystemSounds библиотеки .NET Framework 
            if (this.Name.ToUpper() == "Web".ToUpper())
            {
                SystemSounds.Asterisk.Play();
                return;
            }
    
            // Загрузить асинхронно - в фоновом режиме.
            // Поток для кнопки Stream открывается 
            // один раз в конструкторе клиента
            if (this.Name.ToUpper() != "Stream".ToUpper())
                soundPlayer.LoadAsync();
    
            // Если загрузка закончена, то начинаем проигрывание
            if (soundPlayer.IsLoadCompleted)
                soundPlayer.Play();
            else
                MessageBox.Show("Проигрыватель пока не готов!");
    
            // Подняться до класса Control,
            // чтобы сгенерировать событие Click.
            // Но в этом упражнении не нужно,
            // поскольку не планируем создавать обработчики
            // (хотя можно и оставить незакомментированной)
            // base.OnClick(e);
        }
    }
}
